Test coverage report: online_docs.templatetags.online_docs_tags

# online_docs.templatetags.online_docs_tags: 6 total statements, 100.0% covered

Generated: Sat 2012-06-23 23:31 SGT

Source file: /Users/martin/Repos/django-online-docs/online_docs/templatetags/online_docs_tags.py

Stats: 5 executed, 0 missed, 1 excluded, 6 ignored

1. `"""Templatetags for the ``online_docs`` app."""`
2. `from django import template`
3. ``
4. ``
5. `register = template.Library()`
6. ``
7. ``
8. `@register.simple_tag`
9. `def render_docs_link(request):`
10. `t = template.loader.get_template('online_docs/online_docs_link.html')`
11. `ctx = template.RequestContext(request)`
12. `return t.render(ctx)`